@@ -3,8 +3,8 @@
 use strict;
 use warnings;
 
-our $VERSION = '3.022'; # VERSION
-my $LAST_UPDATE = '2.029'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '2.029'; # manually update whenever code is changed
 
 use PDF::Builder;
 
@@ -27,7 +27,7 @@ foreach my $input_file (@ARGV) {
         print " $page_number,";
         $output_pdf->import_page($input_pdf, $page_number);
     }
-    $input_pdf->end();
+    $input_pdf->close();
     print " Done.\n\n";
 }
 
