@@ -8,6 +8,9 @@
 #   anyone's safety, is implied in this software or documentation.
 #
 #   This specific module is licensed under the Perl Artistic License.
+#   Effective 28 January 2021, the original author and copyright holder, 
+#   Martin Hosken, has given permission to use and redistribute this module 
+#   under the MIT license.
 #
 #=======================================================================
 package PDF::Builder::Basic::PDF::Dict;
@@ -15,10 +18,10 @@ package PDF::Builder::Basic::PDF::Dict;
 use base 'PDF::Builder::Basic::PDF::Objind';
 
 use strict;
-no warnings qw[ deprecated recursion uninitialized ];
+use warnings;
 
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '3.016'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
 
 our $mincache = 16 * 1024 * 1024;
 
@@ -57,10 +60,12 @@ source PDF the stream starts.
 
 =head1 METHODS
 
+=over
+
 =cut
 
 sub new {
-    my ($class) = @_;
+    my $class = shift();  # have @_ used, later
 
     $class = ref($class) if ref($class);
 
@@ -69,7 +74,7 @@ sub new {
     return $self;
 }
 
-=head2 $type = $d->type($type)
+=item $type = $d->type($type)
 
 Get/Set the standard Type key. It can be passed, and will return, a text value rather than a Name object.
 
@@ -85,7 +90,7 @@ sub type {
     return $self->{'Type'}->val();
 }
 
-=head2 @filters = $d->filter(@filters)
+=item @filters = $d->filter(@filters)
 
 Get/Set one or more filters being used by the optional stream attached to the dictionary.
 
@@ -111,7 +116,7 @@ sub filter {
 # Undocumented alias, which may be removed in a future release
 sub filters { return filter(@_); }
 
-=head2 $d->outobjdeep($fh, $pdf)
+=item $d->outobjdeep($fh, $pdf)
 
 Outputs the contents of the dictionary to a PDF file. This is a recursive call.
 
@@ -180,7 +185,7 @@ sub outobjdeep {
     }
 
     if      (defined $self->{' stream'}) {
-        $fh->print(" stream\n");
+        $fh->print("\nstream\n");
         $loc = $fh->tell();
         my $stream = $self->{' stream'};
         unless ($self->{' nofilt'}) {
@@ -195,7 +200,7 @@ sub outobjdeep {
         open(my $dictfh, "<", $self->{' streamfile'}) || die "Unable to open $self->{' streamfile'}";
         binmode($dictfh, ':raw');
 
-        $fh->print(" stream\n");
+        $fh->print("\nstream\n");
         $loc = $fh->tell();
         my $stream;
         while (read($dictfh, $stream, 4096)) {
@@ -229,7 +234,7 @@ sub outobjdeep {
     return;
 }
 
-=head2 $d->read_stream($force_memory)
+=item $d->read_stream($force_memory)
 
 Reads in a stream from a PDF file. If the stream is greater than
 C<PDF::Dict::mincache> (defaults to 32768) bytes to be stored, then
@@ -311,7 +316,7 @@ sub read_stream {
     return $self;
 }
 
-=head2 $d->val()
+=item $d->val()
 
 Returns the dictionary, which is itself.
 
@@ -321,4 +326,8 @@ sub val {
     return $_[0];
 }
 
+=back
+
+=cut
+
 1;
