@@ -8,6 +8,9 @@
 #   anyone's safety, is implied in this software or documentation.
 #
 #   This specific module is licensed under the Perl Artistic License.
+#   Effective 28 January 2021, the original author and copyright holder, 
+#   Martin Hosken, has given permission to use and redistribute this module 
+#   under the MIT license.
 #
 #=======================================================================
 package PDF::Builder::Basic::PDF::Page;
@@ -17,8 +20,8 @@ use base 'PDF::Builder::Basic::PDF::Pages';
 use strict;
 use warnings;
 
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '3.016'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.022'; # manually update whenever code is changed
 
 use PDF::Builder::Basic::PDF::Dict;
 use PDF::Builder::Basic::PDF::Utils;
@@ -49,7 +52,9 @@ The currently open stream
 
 =head1 METHODS
 
-=head2 PDF::Builder::Basic::PDF::Page->new($pdf, $parent, $index)
+=over
+
+=item PDF::Builder::Basic::PDF::Page->new($pdf, $parent, $index)
 
 Creates a new page based on a pages object (perhaps the root object).
 
@@ -82,7 +87,7 @@ sub new {
 # the add() method was deleted from PDF::API2 2.034, but it looks like it
 # still may be used in Builder.pm! apparently calls Content.pm's add().
 
-#=head2 $p->add($str)
+#=item $p->add($str)
 #
 #Adds the string to the currently active stream for this page. If no stream
 #exists, then one is created and added to the list of streams for this page.
@@ -115,7 +120,7 @@ sub new {
 #    return $self;
 #}
 
-=head2 $p->ship_out($pdf)
+=item $p->ship_out($pdf)
 
 Ships the page out to the given output file context
 
@@ -132,4 +137,8 @@ sub ship_out {
     return $self;
 }
 
+=back
+
+=cut
+
 1;
