@@ -8,6 +8,9 @@
 #   anyone's safety, is implied in this software or documentation.
 #
 #   This specific module is licensed under the Perl Artistic License.
+#   Effective 28 January 2021, the original author and copyright holder, 
+#   Martin Hosken, has given permission to use and redistribute this module 
+#   under the MIT license.
 #
 #=======================================================================
 package PDF::Builder::Basic::PDF::String;
@@ -17,8 +20,8 @@ use base 'PDF::Builder::Basic::PDF::Objind';
 use strict;
 use warnings;
 
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '3.016'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
 
 =head1 NAME
 
@@ -27,6 +30,8 @@ for simple objects that are basically stringlike (Number, Name, etc.)
 
 =head1 METHODS
 
+=over
+
 =cut
 
 our %trans = (
@@ -51,7 +56,7 @@ our %out_trans = (
     ')' => ')',
 );
 
-=head2 PDF::Builder::Basic::PDF::String->from_pdf($string)
+=item PDF::Builder::Basic::PDF::String->from_pdf($string)
 
 Creates a new string object (not a full object yet) from a given
 string.  The string is parsed according to input criteria with
@@ -69,7 +74,7 @@ sub from_pdf {
     return $self;
 }
 
-=head2 PDF::Builder::Basic::PDF::String->new($string)
+=item PDF::Builder::Basic::PDF::String->new($string)
 
 Creates a new string object (not a full object yet) from a given
 string. The string is parsed according to input criteria with
@@ -87,7 +92,7 @@ sub new {
     return $self;
 }
 
-=head2 $s->convert($str)
+=item $s->convert($str)
 
 Returns $str converted as per criteria for input from PDF file
 
@@ -166,7 +171,7 @@ sub convert {
     return $output;
 }
 
-=head2 $s->val()
+=item $s->val()
 
 Returns the value of this string (the string itself).
 
@@ -176,7 +181,7 @@ sub val {
     return $_[0]->{'val'};
 }
 
-=head2 $s->as_pdf()
+=item $s->as_pdf()
 
 Returns the string formatted for output as PDF for PDF File object $pdf.
 
@@ -195,17 +200,17 @@ sub as_pdf {
         $str = join('', map { sprintf('%04X' , $_) } unpack('U*', $str) );
         return "<FEFF$str>";
     } else {
-        if ($str =~ m/[^\n\r\t\b\f\040-\176\200-\377]/oi) {
-            $str =~ s/(.)/sprintf('%02X', ord($1))/oge;
+        if ($str =~ m/[^\n\r\t\b\f\040-\176\200-\377]/) {
+            $str =~ s/(.)/sprintf('%02X', ord($1))/sge;
             return "<$str>";
         } else {
-            $str =~ s/([\n\r\t\b\f\\()])/\\$out_trans{$1}/ogi;
+            $str =~ s/([\n\r\t\b\f\\()])/\\$out_trans{$1}/g;
             return "($str)";
         }
     }
 }
 
-=head2 $s->outobjdeep($fh, $pdf)
+=item $s->outobjdeep($fh, $pdf)
 
 Outputs the string in PDF format, complete with necessary conversions.
 
@@ -218,4 +223,8 @@ sub outobjdeep {
     return;
 }
 
+=back
+
+=cut
+
 1;
