@@ -8,6 +8,9 @@
 #   anyone's safety, is implied in this software or documentation.
 #
 #   This specific module is licensed under the Perl Artistic License.
+#   Effective 28 January 2021, the original author and copyright holder, 
+#   Martin Hosken, has given permission to use and redistribute this module 
+#   under the MIT license.
 #
 #=======================================================================
 package PDF::Builder::Basic::PDF::Utils;
@@ -15,8 +18,8 @@ package PDF::Builder::Basic::PDF::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '3.016'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
 
 =head1 NAME
 
@@ -28,6 +31,8 @@ A set of utility functions to save the fingers of the PDF library users!
 
 =head1 FUNCTIONS
 
+=over
+
 =cut
 
 use PDF::Builder::Basic::PDF::Array;
@@ -45,7 +50,7 @@ use vars qw(@EXPORT @ISA);
 @EXPORT = qw(PDFBool PDFArray PDFDict PDFName PDFNull
              PDFNum PDFString PDFStr PDFStrHex PDFUtf);
 
-=head2 PDFBool()
+=item PDFBool()
 
 Creates a Bool via PDF::Builder::Basic::PDF::Bool->new()
 
@@ -55,7 +60,7 @@ sub PDFBool {
     return PDF::Builder::Basic::PDF::Bool->new(@_);
 }
 
-=head2 PDFArray()
+=item PDFArray()
 
 Creates an array via PDF::Builder::Basic::PDF::Array->new()
 
@@ -65,7 +70,7 @@ sub PDFArray {
     return PDF::Builder::Basic::PDF::Array->new(@_);
 }
 
-=head2 PDFDict()
+=item PDFDict()
 
 Creates a dict via PDF::Builder::Basic::PDF::Dict->new()
 
@@ -75,7 +80,7 @@ sub PDFDict {
     return PDF::Builder::Basic::PDF::Dict->new(@_);
 }
 
-=head2 PDFName()
+=item PDFName()
 
 Creates a name via PDF::Builder::Basic::PDF::Name->new()
 
@@ -85,7 +90,7 @@ sub PDFName {
     return PDF::Builder::Basic::PDF::Name->new(@_);
 }
 
-=head2 PDFNull()
+=item PDFNull()
 
 Creates a null via PDF::Builder::Basic::PDF::Null->new()
 
@@ -95,7 +100,7 @@ sub PDFNull {
     return PDF::Builder::Basic::PDF::Null->new(@_);
 }
 
-=head2 PDFNum()
+=item PDFNum()
 
 Creates a number via PDF::Builder::Basic::PDF::Number->new()
 
@@ -105,7 +110,7 @@ sub PDFNum {
     return PDF::Builder::Basic::PDF::Number->new(@_);
 }
 
-=head2 PDFString($text, $usage)
+=item PDFString($text, $usage)
 
 Returns either PDFStr($text) or PDFUtf($text), depending on whether C<$text>
 is already in UTF-8 and whether the C<$usage> permits UTF-8. If UTF-8 is I<not>
@@ -179,7 +184,7 @@ sub PDFString {
     }
 }
 
-=head2 PDFStr()
+=item PDFStr()
 
 Creates a string via PDF::Builder::Basic::PDF::String->new()
 
@@ -191,7 +196,7 @@ sub PDFStr {
     return PDF::Builder::Basic::PDF::String->new(@_);
 }
 
-=head2 PDFStrHex()
+=item PDFStrHex()
 
 Creates a hex-string via PDF::Builder::Basic::PDF::String->new()
 
@@ -203,7 +208,7 @@ sub PDFStrHex {
     return $string;
 }
 
-=head2 PDFUtf()
+=item PDFUtf()
 
 Creates a utf8-string via PDF::Builder::Basic::PDF::String->new()
 
@@ -217,4 +222,8 @@ sub PDFUtf {
     return $string;
 }
 
+=back
+
+=cut
+
 1;
