@@ -5,8 +5,8 @@ use base 'PDF::Builder::Outline';
 use strict;
 use warnings;
 
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '2.029'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
 
 use PDF::Builder::Basic::PDF::Utils;
 
@@ -25,4 +25,9 @@ sub new {
     return $self;
 }
 
+sub count {
+    my $self = shift();
+    return abs($self->SUPER::count());
+}
+
 1;
