@@ -4,10 +4,9 @@ use base 'PDF::Builder::Resource::CIDFont';
 
 use strict;
 use warnings;
-#no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '3.022'; # VERSION
-my $LAST_UPDATE = '3.021'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
 
 use PDF::Builder::Util;
 use PDF::Builder::Basic::PDF::Utils;
@@ -29,19 +28,23 @@ PDF::Builder::Resource::CIDFont::CJKFont - Base class for CJK fonts
 
 Returns a cjk-font object.
 
-Traditional Chinese: Ming Ming-Bold Ming-Italic Ming-BoldItalic
+=over
 
-Simplified Chinese: Song Song-Bold Song-Italic Song-BoldItalic
+* Traditional Chinese: Ming Ming-Bold Ming-Italic Ming-BoldItalic
 
-Korean: MyungJo MyungJo-Bold MyungJo-Italic MyungJo-BoldItalic
+* Simplified Chinese: Song Song-Bold Song-Italic Song-BoldItalic
 
-Japanese (Mincho): KozMin KozMin-Bold KozMin-Italic KozMin-BoldItalic
+* Korean: MyungJo MyungJo-Bold MyungJo-Italic MyungJo-BoldItalic
 
-Japanese (Gothic): KozGo KozGo-Bold KozGo-Italic KozGo-BoldItalic
+* Japanese (Mincho): KozMin KozMin-Bold KozMin-Italic KozMin-BoldItalic
+
+* Japanese (Gothic): KozGo KozGo-Bold KozGo-Italic KozGo-BoldItalic
+
+=back
 
 Defined Options:
 
-    -encode ... specify fonts encoding for non-utf8 text.
+    encode ... specify fonts encoding for non-utf8 text.
 
 =cut
 
@@ -55,20 +58,20 @@ sub _look_for_font {
     if (defined $subs->{$fname}) {
         my $data = _look_for_font($subs->{$fname}->{'-alias'});
         foreach my $k (keys %{$subs->{$fname}}) {
-            next if $k=~/^\-/;
+            next if $k =~ /^\-/;
             if (substr($k, 0, 1) eq '+') {
                 $data->{substr($k, 1)} .= $subs->{$fname}->{$k};
             } else {
                 $data->{$k} = $subs->{$fname}->{$k};
             }
         }
-        $fonts->{$fname}=$data;
-        return ({%{$data}});
+        $fonts->{$fname} = $data;
+        return {%$data};
     }
 
     eval "require 'PDF/Builder/Resource/CIDFont/CJKFont/$fname.data'"; ## no critic
     unless ($@) {
-        return({%{$fonts->{$fname}}});
+        return {%{$fonts->{$fname}}};
     } else {
         die "requested font '$fname' not installed ";
     }
@@ -76,15 +79,16 @@ sub _look_for_font {
 
 # identical routine in Resource/CIDFont/TrueType/FontFile.pm
 sub _look_for_cmap {
-    my $fname = lc(shift);
+    my $map = shift;
+    my $fname = lc($map);
 
     $fname =~ s/[^a-z0-9]+//gi;
-    return ({%{$cmap->{$fname}}}) if defined $cmap->{$fname};
+    return {%{$cmap->{$fname}}} if defined $cmap->{$fname};
     eval "require 'PDF/Builder/Resource/CIDFont/CMap/$fname.cmap'"; ## no critic
     unless ($@) {
-        return({%{$cmap->{$fname}}});
+        return {%{$cmap->{$fname}}};
     } else {
-        die "requested cmap '$fname' not installed ";
+        die "requested cmap '$map' not installed ";
     }
 }
 
@@ -95,7 +99,9 @@ sub new {
 
     my %opts = ();
     %opts = @opts if (scalar @opts)%2 == 0;
-    $opts{'-encode'} ||= 'ident';
+    # copy dashed option names to preferred undashed names
+    if (defined $opts{'-encode'} && !defined $opts{'encode'}) { $opts{'encode'} = delete($opts{'-encode'}); }
+    $opts{'encode'} ||= 'ident';
 
     my $data = _look_for_font($name);
 
@@ -105,17 +111,15 @@ sub new {
     $data->{'g2u'} = [ @{$cmap->{'g2u'}} ];
 
     $class = ref $class if ref $class;
-    my $self = $class->SUPER::new($pdf, (defined($data->{'apiname'})? $data->{'apiname'}: '').pdfkey());
+    # ensure that apiname is initialized
+    my $key = ($data->{'apiname'} // '') . pdfkey();
+    my $self = $class->SUPER::new($pdf, $key);
     $pdf->new_obj($self) if defined($pdf) && !$self->is_obj($pdf);
 
     $self->{' data'} = $data;
 
-    my $des = $self->descrByData();
-
-    my $de = $self->{' de'};
-
-    if (defined $opts{'-encode'} && $opts{'-encode'} ne 'ident') {
-        $self->data->{'encode'} = $opts{'-encode'};
+    if (defined $opts{'encode'} && $opts{'encode'} ne 'ident') {
+        $self->data->{'encode'} = $opts{'encode'};
     }
 
     my $emap = {
@@ -133,9 +137,9 @@ sub new {
         $emap->{'sup'} = $cmap->{'ccs'}->[2];
     }
 
-    #if      (defined $cmap->{'cmap'} && defined $cmap->{'cmap'}->{$opts{'-encode'}} ) {
-    #    $emap->{'dec'} = $cmap->{'cmap'}->{$opts{'-encode'}}->[0];
-    #    $emap->{'map'} = $cmap->{'cmap'}->{$opts{'-encode'}}->[1];
+    #if      (defined $cmap->{'cmap'} && defined $cmap->{'cmap'}->{$opts{'encode'}} ) {
+    #    $emap->{'dec'} = $cmap->{'cmap'}->{$opts{'encode'}}->[0];
+    #    $emap->{'map'} = $cmap->{'cmap'}->{$opts{'encode'}}->[1];
     #} elsif (defined $cmap->{'cmap'} && defined $cmap->{'cmap'}->{'utf8'}) {
     #    $emap->{'dec'} = $cmap->{'cmap'}->{'utf8'}->[0];
     #    $emap->{'map'} = $cmap->{'cmap'}->{'utf8'}->[1];
@@ -143,8 +147,16 @@ sub new {
 
     $self->data()->{'decode'} = $emap->{'dec'};
 
-    $self->{'BaseFont'} = PDFName($self->fontname()."-$emap->{'map'}-$emap->{'dir'}");
-    $self->{'Encoding'} = PDFName("$emap->{'map'}-$emap->{'dir'}");
+    $self->{'BaseFont'} = PDFName(join('-',
+		                       $self->fontname(),
+				       $emap->{'map'},
+				       $emap->{'dir'}));
+    $self->{'Encoding'} = PDFName(join('-',
+		                       $emap->{'map'},
+				       $emap->{'dir'}));
+
+    my $des = $self->descrByData();
+    my $de = $self->{' de'};
 
     $de->{'FontDescriptor'} = $des;
     $de->{'Subtype'} = PDFName('CIDFontType0');
@@ -159,7 +171,7 @@ sub new {
 }
 
 sub tounicodemap {
-    my $self = shift @_;
+    my $self = shift;
 
     # no-op since PDF knows its char-collection
     return $self;
@@ -181,35 +193,25 @@ sub outobjdeep {
     $self->{' de'}->{'W'} = $wx;
     my $ml;
 
-    foreach my $w (0 .. (scalar @{$self->data()->{'g2u'}} - 1 )) {
+    foreach my $i (0 .. (scalar @{$self->data()->{'g2u'}} - 1 )) {
         if      (ref($self->data()->{'wx'}) eq 'ARRAY' &&
-            (defined $self->data()->{'wx'}->[$w]) &&
-            ($self->data()->{'wx'}->[$w] != $self->missingwidth()) &&
-            $notdefbefore == 1) {
-            $notdefbefore = 0;
-            $ml = PDFArray();
-            $wx->add_elements(PDFNum($w), $ml);
-            $ml->add_elements(PDFNum($self->data()->{'wx'}->[$w]));
+            (defined $self->data()->{'wx'}->[$i]) &&
+            ($self->data()->{'wx'}->[$i] != $self->missingwidth()) ) {
+            if ($notdefbefore) {
+                $notdefbefore = 0;
+                $ml = PDFArray();
+                $wx->add_elements(PDFNum($i), $ml);
+	    }
+            $ml->add_elements(PDFNum($self->data()->{'wx'}->[$i]));
         } elsif (ref($self->data()->{'wx'}) eq 'HASH' &&
-            (defined $self->data()->{'wx'}->{$w}) &&
-            ($self->data()->{'wx'}->{$w} != $self->missingwidth()) &&
-            $notdefbefore == 1) {
-            $notdefbefore = 0;
-            $ml = PDFArray();
-            $wx->add_elements(PDFNum($w), $ml);
-            $ml->add_elements(PDFNum($self->data()->{'wx'}->{$w}));
-        } elsif (ref($self->data()->{'wx'}) eq 'ARRAY' &&
-            (defined $self->data()->{'wx'}->[$w]) &&
-            ($self->data()->{'wx'}->[$w] != $self->missingwidth()) &&
-            $notdefbefore == 0) {
-            $notdefbefore = 0;
-            $ml->add_elements(PDFNum($self->data()->{'wx'}->[$w]));
-        } elsif (ref($self->data()->{'wx'}) eq 'HASH' &&
-            (defined $self->data()->{'wx'}->{$w}) &&
-            ($self->data()->{'wx'}->{$w} != $self->missingwidth()) &&
-            $notdefbefore == 0) {
-            $notdefbefore = 0;
-            $ml->add_elements(PDFNum($self->data()->{'wx'}->{$w}));
+            (defined $self->data()->{'wx'}->{$i}) &&
+            ($self->data()->{'wx'}->{$i} != $self->missingwidth()) ) {
+            if ($notdefbefore) {
+                $notdefbefore = 0;
+                $ml = PDFArray();
+                $wx->add_elements(PDFNum($i), $ml);
+	    }
+            $ml->add_elements(PDFNum($self->data()->{'wx'}->{$i}));
         } else {
             $notdefbefore = 1;
         }
@@ -250,68 +252,68 @@ BEGIN {
     $subs = {
     # Chinese Traditional (i.e., ROC/Taiwan) Fonts
         'mingitalic' => {
-            '-alias'            => 'adobemingstdlightacro',
-            '+fontname'         => ',Italic',
+            '-alias'    => 'adobemingstdlightacro',
+            '+fontname' => ',Italic',
         },
         'mingbold' => {
-            '-alias'            => 'adobemingstdlightacro',
-            '+fontname'         => ',Bold',
+            '-alias'    => 'adobemingstdlightacro',
+            '+fontname' => ',Bold',
         },
         'mingbolditalic' => {
-            '-alias'            => 'adobemingstdlightacro',
-            '+fontname'         => ',BoldItalic',
+            '-alias'    => 'adobemingstdlightacro',
+            '+fontname' => ',BoldItalic',
         },
     # Chinese Simplified (i.e., PRC/Mainland China) Fonts
         'songitalic' => {
-            '-alias'            => 'adobesongstdlightacro',
-            '+fontname'         => ',Italic',
+            '-alias'    => 'adobesongstdlightacro',
+            '+fontname' => ',Italic',
         },
         'songbold' => {
-            '-alias'            => 'adobesongstdlightacro',
-            '+fontname'         => ',Bold',
+            '-alias'    => 'adobesongstdlightacro',
+            '+fontname' => ',Bold',
         },
         'songbolditalic' => {
-            '-alias'            => 'adobesongstdlightacro',
-            '+fontname'         => ',BoldItalic',
+            '-alias'    => 'adobesongstdlightacro',
+            '+fontname' => ',BoldItalic',
         },
     # Japanese Gothic (i.e., sans serif) Fonts
         'kozgoitalic' => {
-            '-alias'            => 'kozgopromediumacro',
-            '+fontname'         => ',Italic',
+            '-alias'    => 'kozgopromediumacro',
+            '+fontname' => ',Italic',
         },
         'kozgobold' => {
-            '-alias'            => 'kozgopromediumacro',
-            '+fontname'         => ',Bold',
+            '-alias'    => 'kozgopromediumacro',
+            '+fontname' => ',Bold',
         },
         'kozgobolditalic' => {
-            '-alias'            => 'kozgopromediumacro',
-            '+fontname'         => ',BoldItalic',
+            '-alias'    => 'kozgopromediumacro',
+            '+fontname' => ',BoldItalic',
         },
     # Japanese Mincho (i.e., serif) Fonts
         'kozminitalic' => {
-            '-alias'            => 'kozminproregularacro',
-            '+fontname'         => ',Italic',
+            '-alias'    => 'kozminproregularacro',
+            '+fontname' => ',Italic',
         },
         'kozminbold' => {
-            '-alias'            => 'kozminproregularacro',
-            '+fontname'         => ',Bold',
+            '-alias'    => 'kozminproregularacro',
+            '+fontname' => ',Bold',
         },
         'kozminbolditalic' => {
-            '-alias'            => 'kozminproregularacro',
-            '+fontname'         => ',BoldItalic',
+            '-alias'    => 'kozminproregularacro',
+            '+fontname' => ',BoldItalic',
         },
     # Korean Fonts
         'myungjoitalic' => {
-            '-alias'            => 'adobemyungjostdmediumacro',
-            '+fontname'         => ',Italic',
+            '-alias'    => 'adobemyungjostdmediumacro',
+            '+fontname' => ',Italic',
         },
         'myungjobold' => {
-            '-alias'            => 'adobemyungjostdmediumacro',
-            '+fontname'         => ',Bold',
+            '-alias'    => 'adobemyungjostdmediumacro',
+            '+fontname' => ',Bold',
         },
         'myungjobolditalic' => {
-            '-alias'            => 'adobemyungjostdmediumacro',
-            '+fontname'         => ',BoldItalic',
+            '-alias'    => 'adobemyungjostdmediumacro',
+            '+fontname' => ',BoldItalic',
         },
     };
 
