@@ -3,13 +3,18 @@ package PDF::Builder::Resource::Colors;
 use strict;
 use warnings;
 
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '2.029'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
 
 =head1 NAME
 
 PDF::Builder::Resource::Colors - translate color names into RGB settings
 
+=head1 SYNOPSIS
+
+This list is an amalgamation of the X11, SGML, and (X)HTML 
+color specification sets.
+
 =cut
 
 sub get_colors {
