@@ -5,8 +5,8 @@ use base 'PDF::Builder::Resource::XObject::Form::BarCode';
 use strict;
 use warnings;
 
-our $VERSION = '3.021'; # VERSION
-my $LAST_UPDATE = '2.029'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
 
 =head1 NAME
 
@@ -14,12 +14,16 @@ PDF::Builder::Resource::XObject::Form::BarCode::codabar - specific information f
 
 =cut
 
+# TBD document code, caption options
+
 sub new {
     my ($class, $pdf, %options) = @_;
+    # copy dashed option names to preferred undashed names
+    if (defined $options{'-code'} && !defined $options{'code'}) { $options{'code'} = delete($options{'-code'}); }
 
     my $self = $class->SUPER::new($pdf, %options);
 
-    my @bars = $self->encode($options{'-code'});
+    my @bars = $self->encode($options{'code'});
 
     $self->drawbar([@bars], $options{'caption'});
 
