@@ -4,10 +4,9 @@ use base 'PDF::Builder::Resource::XObject::Image';
 
 use strict;
 use warnings;
-#no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '3.021'; # VERSION
-my $LAST_UPDATE = '3.021'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
 
 use PDF::Builder::Util;
 use PDF::Builder::Basic::PDF::Utils;
@@ -17,22 +16,52 @@ use Scalar::Util qw(weaken);
 
 PDF::Builder::Resource::XObject::Image::GD - support routines for Graphics Development image library. Inherits from L<PDF::Builder::Resource::XObject::Image>
 
+=head1 METHODS
+
+=over 
+
+=item $res = PDF::Builder::Resource::XObject::Image::GD->new($pdf, $file, %opts)
+
+Options:
+
+=over
+
+=item 'name' => 'string'
+
+This is the name you can give for the GD image object. The default is Dxnnnn.
+
+=item 'lossless' => 1
+
+Use lossless compression.
+
+=back
+
+=back
+
 =cut
 
 sub new {
-    my ($class, $pdf, $obj, $name, @opts) = @_;
+    my ($class, $pdf, $obj, %opts) = @_;
+    # copy dashed option names to preferred undashed names
+    if (defined $opts{'-name'} && !defined $opts{'name'}) { $opts{'name'} = delete($opts{'-name'}); }
+    if (defined $opts{'-compress'} && !defined $opts{'compress'}) { $opts{'compress'} = delete($opts{'-compress'}); }
+    if (defined $opts{'-lossless'} && !defined $opts{'lossless'}) { $opts{'lossless'} = delete($opts{'-lossless'}); }
+
+    my ($name, $compress);
+    if (exists $opts{'name'}) { $name = $opts{'name'}; }
+   #if (exists $opts{'compress'}) { $compress = $opts{'compress'}; }
 
     my $self;
 
-    $class = ref $class if ref $class;
+    $class = ref($class) if ref($class);
 
-    $self = $class->SUPER::new($pdf, $name || 'Jx'.pdfkey());
+    $self = $class->SUPER::new($pdf, $name || 'Dx'.pdfkey());
     $pdf->new_obj($self) unless $self->is_obj($pdf);
 
     $self->{' apipdf'} = $pdf;
     weaken $self->{' apipdf'};
 
-    $self->read_gd($obj, @opts);
+    $self->read_gd($obj, %opts);
 
     return $self;
 }
@@ -49,7 +78,7 @@ sub read_gd {
     $self->bits_per_component(8);
     $self->colorspace('DeviceRGB');
 
-    if ($gd->can('jpeg') && ($c > 256) && !$opts{'-lossless'}) {
+    if ($gd->can('jpeg') && ($c > 256) && !$opts{'lossless'}) {
 
         $self->filters('DCTDecode');
         $self->{' nofilt'} = 1;
