@@ -5,8 +5,8 @@ use base 'PDF::Builder::Resource::XObject::Image';
 use strict;
 use warnings;
 
-our $VERSION = '3.022'; # VERSION
-my $LAST_UPDATE = '3.017'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
 
 use IO::File;
 use PDF::Builder::Util;
@@ -17,14 +17,39 @@ use Scalar::Util qw(weaken);
 
 PDF::Builder::Resource::XObject::Image::JPEG - support routines for JPEG image library. Inherits from L<PDF::Builder::Resource::XObject::Image>
 
+=head1 METHODS
+
+=over
+
+=item $res = PDF::Builder::Resource::XObject::Image::JPEG->new($pdf, $file, %opts)
+
+Options:
+
+=over
+
+=item 'name' => 'string'
+
+This is the name you can give for the JPEG image object. The default is Jxnnnn.
+
+=back
+
+=back
+
 =cut
 
 sub new {
-    my ($class, $pdf, $file, $name) = @_;
+    my ($class, $pdf, $file, %opts) = @_;
+    # copy dashed option names to preferred undashed names
+    if (defined $opts{'-name'} && !defined $opts{'name'}) { $opts{'name'} = delete($opts{'-name'}); }
+    if (defined $opts{'-compress'} && !defined $opts{'compress'}) { $opts{'compress'} = delete($opts{'-compress'}); }
+
+    my ($name, $compress);
+    if (exists $opts{'name'}) { $name = $opts{'name'}; }
+   #if (exists $opts{'compress'}) { $compress = $opts{'compress'}; }
 
     my $fh = IO::File->new();
 
-    $class = ref($class) if ref $class;
+    $class = ref($class) if ref($class);
 
     my $self = $class->SUPER::new($pdf, $name || 'Jx' . pdfkey());
     $pdf->new_obj($self) unless $self->is_obj($pdf);
