@@ -5,10 +5,8 @@ use base 'PDF::Builder::Resource::XObject::Image';
 use strict;
 use warnings;
 
-#no warnings 'uninitialized';
-
-our $VERSION = '3.022'; # VERSION
-my $LAST_UPDATE = '3.022'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
 
 use Compress::Zlib;
 
@@ -25,24 +23,40 @@ PDF::Builder::Resource::XObject::Image::TIFF - TIFF image support
 
 =over
 
-=item  $res = PDF::Builder::Resource::XObject::Image::TIFF->new($pdf, $file, $name)
-
-=item  $res = PDF::Builder::Resource::XObject::Image::TIFF->new($pdf, $file)
+=item  $res = PDF::Builder::Resource::XObject::Image::TIFF->new($pdf, $file, %opts)
 
 Returns a TIFF-image object.
 
 If the Graphics::TIFF package is installed, the TIFF_GT library will be used
 instead of the TIFF library. In such a case, use of the TIFF library may be 
-forced via the C<-nouseGT> flag (see Builder documentation for C<image_tiff()>).
+forced via the C<nouseGT> flag (see Builder documentation for C<image_tiff()>).
+
+Options:
+
+=over
+
+=item 'name' => 'string'
+
+This is the name you can give for the TIFF image object. The default is Ixnnnn.
+
+=back
 
 =cut
 
 sub new {
-    my ($class, $pdf, $file, $name) = @_;
+    my ($class, $pdf, $file, %opts) = @_;
+    # copy dashed option names to preferred undashed names
+    if (defined $opts{'-nouseGT'} && !defined $opts{'nouseGT'}) { $opts{'nouseGT'} = delete($opts{'-nouseGT'}); }
+    if (defined $opts{'-name'} && !defined $opts{'name'}) { $opts{'name'} = delete($opts{'-name'}); }
+    if (defined $opts{'-compress'} && !defined $opts{'compress'}) { $opts{'compress'} = delete($opts{'-compress'}); }
+
+    my ($name, $compress);
+    if (exists $opts{'name'}) { $name = $opts{'name'}; }
+   #if (exists $opts{'compress'}) { $compress = $opts{'compress'}; }
 
     my $self;
 
-    my $tif = PDF::Builder::Resource::XObject::Image::TIFF::File->new($file);
+    my $tif = PDF::Builder::Resource::XObject::Image::TIFF::File->new($file, %opts);
 
  # dump everything in tif except huge data streams
 # foreach (sort keys %{ $tif }) {
@@ -60,7 +74,7 @@ sub new {
     # in case of problematic things
     #  proxy to other modules
 
-    $class = ref($class) if ref $class;
+    $class = ref($class) if ref($class);
 
     $self = $class->SUPER::new($pdf, $name || 'Ix'.pdfkey());
     $pdf->new_obj($self) unless $self->is_obj($pdf);
@@ -78,7 +92,7 @@ sub new {
 =item  $mode = $tif->usesLib()
 
 Returns 1 if Graphics::TIFF installed and used, 0 if not installed, or -1 if
-installed but not used (-nouseGT option given to C<image_tiff>).
+installed but not used (nouseGT option given to C<image_tiff>).
 
 B<Caution:> this method can only be used I<after> the image object has been
 created. It can't tell you whether Graphics::TIFF is available in
@@ -95,55 +109,6 @@ sub usesLib {
     return $self->{'usesGT'}->val();
 }
 
-sub deLZW {
-    my ($ibits, $stream) = @_;
-
-    my $bits = $ibits;
-    my $resetcode = 1 << ($ibits - 1);
-    my $endcode = $resetcode + 1;
-    my $nextcode = $endcode + 1;
-    my $ptr = 0;
-    $stream = unpack('B*', $stream);
-    my $maxptr = length($stream);
-    my $tag;
-    my $out = '';
-    my $outptr = 0;
-
-    # print STDERR "reset=$resetcode\nend=$endcode\nmax=$maxptr\n";
-
-    my @d = map { chr($_) } (0 .. $resetcode-1);
-
-    while ($ptr+$bits <= $maxptr) {
-        $tag = 0;
-        foreach my $off (reverse 1 .. $bits) {
-            $tag <<= 1;
-            $tag |= substr($stream, $ptr+$bits-$off, 1);
-        }
-        # print STDERR "ptr=$ptr,tag=$tag,bits=$bits,next=$nextcode\n";
-        # print STDERR "tag to large\n" if($tag>$nextcode);
-        $ptr += $bits;
-        if      ($tag == $resetcode) {
-            $bits = $ibits;
-            $nextcode = $endcode+1;
-            next;
-        } elsif ($tag == $endcode) {
-            last;
-        } elsif ($tag < $resetcode) {
-            $d[$nextcode] = $d[$tag];
-            $out .= $d[$nextcode];
-            $nextcode++;
-        } elsif ($tag > $endcode) {
-            $d[$nextcode] = $d[$tag];
-            $d[$nextcode] .= substr($d[$tag+1], 0, 1);
-            $out .= $d[$nextcode];
-            $nextcode++;
-        }
-        $bits++ if $nextcode == (1 << $bits);
-    }
-
-    return $out;
-}
-
 sub handle_generic {
     my ($self, $pdf, $tif) = @_;
 
@@ -200,31 +165,34 @@ sub handle_flate {
 sub handle_lzw {
     my ($self, $pdf, $tif) = @_;
 
-    $self->filters('FlateDecode');
-    my $imageWidth = $tif->{'imageWidth'};
-    my $mod = $imageWidth%8;
-    if ($mod > 0) {
-	$imageWidth += 8-$mod;
+    $self->{' nofilt'} = 1;
+    $self->{'Filter'} = PDFArray(PDFName('LZWDecode'));
+    my $decode = PDFDict();
+    $self->{'DecodeParms'} = PDFArray($decode);
+    $decode->{'Columns'} = PDFNum($tif->{'imageWidth'});
+    $decode->{'Rows'} = PDFNum($tif->{'imageHeight'});
+    $decode->{'DamagedRowsBeforeError'} = PDFNum(100);
+    $decode->{'EndOfLine'} = PDFBool(1);
+    $decode->{'EncodedByteAlign'} = PDFBool(1);
+    if (defined $tif->{'Predictor'} and $tif->{'Predictor'} > 1) {
+        $decode->{'Predictor'} = PDFNum($tif->{'Predictor'});
     }
-    my $max_raw_strip = $imageWidth*$tif->{'bitsPerSample'}*$tif->{'RowsPerStrip'}/8;
 
     if (ref($tif->{'imageOffset'})) {
         $self->{' stream'} = '';
         my $d = scalar @{$tif->{'imageOffset'}};
         foreach (1 .. $d) {
-            my $buf;
             $tif->{'fh'}->seek(shift(@{$tif->{'imageOffset'}}), 0);
+            my $buf;
             $tif->{'fh'}->read($buf, shift(@{$tif->{'imageLength'}}));
-            $buf = deLZW(9, $buf);
-            if (length($buf) > $max_raw_strip) {
-                $buf = substr($buf, 0, $max_raw_strip);
-            }
-            $self->{' stream'} .= $buf;
+            my $filter = PDF::Builder::Basic::PDF::Filter::LZWDecode->new();
+            $self->{' stream'} .= $filter->infilt($buf);
         }
+        my $filter = PDF::Builder::Basic::PDF::Filter::LZWDecode->new();
+        $self->{' stream'} = $filter->outfilt($self->{' stream'});
     } else {
         $tif->{'fh'}->seek($tif->{'imageOffset'}, 0);
         $tif->{'fh'}->read($self->{' stream'}, $tif->{'imageLength'});
-        $self->{' stream'} = deLZW(9, $self->{' stream'});
     }
 
     return $self;
@@ -236,10 +204,12 @@ sub handle_ccitt {
     $self->{' nofilt'} = 1;
     $self->{'Filter'} = PDFName('CCITTFaxDecode');
     $self->{'DecodeParms'} = PDFDict();
-    $self->{'DecodeParms'}->{'K'} = (($tif->{'ccitt'} == 4 || (($tif->{'g3Options'}||0) & 0x1))? PDFNum(-1): PDFNum(0));
+    $self->{'DecodeParms'}->{'K'} = ($tif->{'ccitt'} == 4 || 
+        (($tif->{'g3Options'}||0) & 0x1))? PDFNum(-1): PDFNum(0);
     $self->{'DecodeParms'}->{'Columns'} = PDFNum($tif->{'imageWidth'});
     $self->{'DecodeParms'}->{'Rows'} = PDFNum($tif->{'imageHeight'});
-    $self->{'DecodeParms'}->{'BlackIs1'} = PDFBool($tif->{'whiteIsZero'} == 0? 1: 0);
+    $self->{'DecodeParms'}->{'BlackIs1'} = 
+        PDFBool(($tif->{'whiteIsZero'}||0) == 0? 1: 0);
     if (defined($tif->{'g3Options'}) && ($tif->{'g3Options'} & 0x4)) {
         $self->{'DecodeParms'}->{'EndOfLine'} = PDFBool(1);
         $self->{'DecodeParms'}->{'EncodedByteAlign'} = PDFBool(1);
@@ -265,14 +235,16 @@ sub read_tiff {
     if ($tif->{'colorSpace'} eq 'Indexed') {
         my $dict = PDFDict();
         $pdf->new_obj($dict);
-        $self->colorspace(PDFArray(PDFName($tif->{'colorSpace'}), PDFName('DeviceRGB'), PDFNum(2**$tif->{'bitsPerSample'}-1), $dict));
+        $self->colorspace(PDFArray(PDFName($tif->{'colorSpace'}), 
+	    	PDFName('DeviceRGB'), PDFNum(2**$tif->{'bitsPerSample'}-1), $dict));
         $dict->{'Filter'} = PDFArray(PDFName('FlateDecode'));
         $tif->{'fh'}->seek($tif->{'colorMapOffset'}, 0);
         my $colormap;
         my $straight;
         $tif->{'fh'}->read($colormap, $tif->{'colorMapLength'});
         $dict->{' stream'} = '';
-        $straight .= pack('C', ($_/256)) for unpack($tif->{'short'} . '*', $colormap);
+        $straight .= pack('C', ($_/256)) for 
+	    	unpack($tif->{'short'} . '*', $colormap);
         foreach my $c (0 .. (($tif->{'colorMapSamples'}/3)-1)) {
             $dict->{' stream'} .= substr($straight, $c, 1);
             $dict->{' stream'} .= substr($straight, $c + ($tif->{'colorMapSamples'}/3), 1);
@@ -359,6 +331,7 @@ sub tiffTag {
 }
 
 =back
+
 =cut
 
 1;
