@@ -3,8 +3,8 @@ package PDF::Builder::Resource::XObject::Image::TIFF::File;
 use strict;
 use warnings;
 
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '3.001'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.023'; # manually update whenever code is changed
 
 use IO::File;
 
@@ -233,7 +233,7 @@ sub readTags {
                 $self->{'colorMapSamples'} = $valCount;
                 $self->{'colorMapLength'} = $valCount*2; # shorts!
             } elsif ($valTag == 317) {
-                $self->{'lzwPredictor'} = $valOffset;
+                $self->{'Predictor'} = $valOffset;
             } elsif ($valTag == 0x800d) {
                 # imageID
                 my $here = $fh->tell();
