@@ -1,10 +1,10 @@
 package PDF::Builder::UniWrap;
 
 use strict;
-no warnings qw[ deprecated recursion uninitialized ];
+use warnings;
 
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '3.010'; # manually update whenever code is changed
+our $VERSION = '3.024'; # VERSION
+our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
 
 =head1 NAME
 
@@ -31,7 +31,6 @@ our $DEBUG = 0;
 our $columns = 75;
 
 my %classified;
-my $procedural_self;
 my $txt;
 
 use constant PROHIBITED => 0;  ## no critic
@@ -147,7 +146,6 @@ sub text_properties {
 # Returns a list of breaking properties for the provided breaking classes
 sub class_properties {
     my $self = ref($_[0])? shift(): self();
-    no warnings 'uninitialized';
 
     my @breaks;
     my $last_class = $_[0];
@@ -218,8 +216,6 @@ sub find_breaks {
     my $self = ref($_[0])? shift(): self();
     my $text = shift;
 
-    no warnings 'uninitialized';    # since we do a lot of subscript +/- 1 checks
-
     my @characters = split(//, $text);
 
     my @classifications = map { $self->lb_class($_) } @characters;
